@@ -25,15 +25,20 @@
 #include "kmplotio.h"
 
 // Qt includes
-#include <qdom.h>
-#include <qfile.h>
+#include <QDebug>
+#include <QDomDocument>
+#include <QDomElement>
+#include <QDomNode>
+#include <QDomText>
+#include <QFile>
 #include <QTextStream>
+#include <QTemporaryFile>
 
 // KDE includes
-#include <kdebug.h>
-#include <kio/netaccess.h>
-#include <kmessagebox.h>
-#include <ktemporaryfile.h>
+#include <KIO/StoredTransferJob>
+#include <KJobWidgets>
+#include <KMessageBox>
+#include <KLocalizedString>
 
 // ANSI-C includes
 #include <stdlib.h>
@@ -127,10 +132,10 @@ bool KmPlotIO::save( const QUrl &url )
 
 	if (!url.isLocalFile() )
 	{
-		KTemporaryFile tmpfile;
+		QTemporaryFile tmpfile;
 		if ( !tmpfile.open() )
 		{
-		    kWarning() << "Could not open " 
+		    qWarning() << "Could not open " 
 			       << QUrl( tmpfile.fileName() ).toLocalFile() << " for writing.\n";
 		    return false;
 		}
@@ -138,17 +143,22 @@ bool KmPlotIO::save( const QUrl &url )
 		doc.save( ts, 4 );
 		ts.flush();
 
-		if ( !KIO::NetAccess::upload(tmpfile.fileName(), url,0)) {
-		    kWarning() << "Could not open " << url.toString() 
-			       << " for writing ("<<KIO::NetAccess::lastErrorString()<<").\n";
+		Q_CONSTEXPR int permission = -1;
+		QFile file(tmpfile.fileName());
+		file.open(QIODevice::ReadOnly);
+		KIO::StoredTransferJob *putjob = KIO::storedPut(file.readAll(), url, permission, KIO::JobFlag::Overwrite);
+		if (!putjob->exec()) {
+		    qWarning() << "Could not open " << url.toString() 
+			       << " for writing ("<<putjob->errorString()<<").\n";
 		    return false;
 		}
+		file.close();
 	}
 	else {
 	    QFile xmlfile (url.toLocalFile());
 	    if (!xmlfile.open( QIODevice::WriteOnly ) )
 		{
-		    kWarning() << "Could not open " << url.path() << " for writing.\n";
+		    qWarning() << "Could not open " << url.path() << " for writing.\n";
 		    return false;
 		}
 	    QTextStream ts( &xmlfile );
@@ -334,20 +344,27 @@ bool KmPlotIO::load( const QUrl &url )
 {
 	QDomDocument doc( "kmpdoc" );
 	QFile f;
+	bool downloadedFile = false;
 	if ( !url.isLocalFile() )
 	{
-		if( !KIO::NetAccess::exists( url, KIO::NetAccess::SourceSide, 0 ) )
+		if( !MainDlg::fileExists( url ) )
 		{
 			KMessageBox::sorry(0,i18n("The file does not exist."));
 			return false;
 		}
-		QString tmpfile;
-		if( !KIO::NetAccess::download( url, tmpfile, 0 ) )
-		{
-			KMessageBox::sorry(0,i18n("An error appeared when opening this file (%1)", KIO::NetAccess::lastErrorString() ));
-			return false;
+		downloadedFile = true;
+		KIO::StoredTransferJob *transferjob = KIO::storedGet (url);
+		KJobWidgets::setWindow(transferjob, 0);
+		if ( !transferjob->exec() ) {
+		    KMessageBox::sorry(0,i18n("An error appeared when opening this file (%1)", transferjob->errorString() ));
+		    return false;
 		}
-		f.setFileName(tmpfile);
+		QTemporaryFile file;
+		file.setAutoRemove(false);
+		file.open();
+		file.write(transferjob->data());
+		f.setFileName(file.fileName());
+		file.close();
 	}
 	else
 		f.setFileName( url.toLocalFile() );
@@ -370,8 +387,8 @@ bool KmPlotIO::load( const QUrl &url )
 	if ( !restore( doc ) )
 		return false;
 
-	if ( !url.isLocalFile() )
-		KIO::NetAccess::removeTempFile( f.fileName() );
+	if ( downloadedFile )
+		QFile::remove( f.fileName() );
 	return true;
 }
 
@@ -508,7 +525,7 @@ void KmPlotIO::parseFunction( const QDomElement & n, bool allowRename )
 	int functionID = XParser::self()->Parser::addFunction( eq0, eq1, type, true );
 	if ( functionID == -1 )
 	{
-		kWarning() << "Could not create function!\n";
+		qWarning() << "Could not create function!\n";
 		return;
 	}
 	Function * function = XParser::self()->functionWithID( functionID );
@@ -597,7 +614,7 @@ void KmPlotIO::parseDifferentialStates( const QDomElement & n, Equation * equati
 			DifferentialState * state = equation->differentialStates.add();
 			if ( state->y0.size() != y.size() )
 			{
-				kWarning() << "Invalid y count!\n";
+				qWarning() << "Invalid y count!\n";
 				return;
 			}
 			
@@ -729,7 +746,7 @@ void KmPlotIO::oldParseFunction( const QDomElement & n )
 	QString tmp_fstr = n.namedItem( "equation" ).toElement().text();
 	if ( tmp_fstr.isEmpty() )
 	{
-		kWarning() << "tmp_fstr is empty!\n";
+		qWarning() << "tmp_fstr is empty!\n";
 		return;
 	}
 	
